@@ -1,6 +1,7 @@
 use std::error;
 use std::fmt;
 use std::io;
+use std::convert;
 
 /// Contains error options that can be encountered while performing the decoding
 /// operations.
@@ -30,6 +31,12 @@ impl From<io::Error> for DecoderError {
     }
 }
 
+impl From<convert::Infallible> for DecoderError { // until solved: https://github.com/rust-lang/rust/issues/64715
+    fn from(_: convert::Infallible) -> Self {
+        unreachable!()
+    }
+}
+
 impl fmt::Display for DecoderError {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
         match self {
