@@ -1,6 +1,7 @@
 use std::error;
 use std::fmt;
 use std::io;
+use std::convert;
 
 /// Contains error options that can be encountered while performing the encoding
 /// operations.
@@ -25,6 +26,12 @@ impl From<io::Error> for EncoderError {
     }
 }
 
+impl From<convert::Infallible> for EncoderError { // until solved: https://github.com/rust-lang/rust/issues/64715
+    fn from(_: convert::Infallible) -> Self {
+        unreachable!()
+    }
+}
+
 impl fmt::Display for EncoderError {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
         match self {
